from django.utils.translation import gettext_lazy as _
from rest_framework_simplejwt.authentication import JWTAuthentication
from rest_framework_simplejwt.exceptions import InvalidToken

from auth_protection.utils import get_protect_key


class JWTAuthProtection(JWTAuthentication):
    """
    This class will check the user token, If the user password is changed, the user will be logout from the system.
    """

    def get_user(self, validated_token):
        user = super().get_user(validated_token)

        if validated_token.get('protect_key') != get_protect_key(user):
            raise InvalidToken(_('Token contained no recognizable user identification'))

        return user



from rest_framework_simplejwt.serializers import TokenObtainPairSerializer

from auth_protection.utils import get_protect_key


class ProtectTokenObtainPairSerializer(TokenObtainPairSerializer):
    """
    Protect TokenObtainPairSerializer: This class is a custom TokenObtainPairSerializer to detect change passwords and
     logout user when password changed in REST API
    """

    @classmethod
    def get_token(cls, user):
        token = super().get_token(user)
        token['protect_key'] = get_protect_key(user)
        return token



import os

from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-auth-protection',
    version='1.0.2',
    zip_safe=False,
    packages=find_packages(),
    include_package_data=True,
    description='Logout users when the passwords changed in REST API',
    long_description=README,
    long_description_content_type="text/markdown",
    url='https://github.com/imankarimi/django-auth-protection',
    author='Iman Karimi',
    author_email='imankarimi.mail@gmail.com',
    license='MIT License',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 3.2',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Environment :: Web Environment',
        'Topic :: Software Development',
    ],
)
